Documentation
¶
Overview ¶
Package ciexec implements functions to execute some CI configuration scripts.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Exec ¶
Exec detects the file's CI format type and executes it passing CI-specific detail string. It writes outputs from any commands it executes to the w.
func ExecBash ¶
ExecBash runs script expressions in a single bash session. Execution loop does not stop, even if one of the commands exits with a code != 0. The function returns the last error encountered, if any.
func ExecCmd ¶
ExecCmd runs commands in order they're stored in cmds, writing combined output from each command to w. Execution loop does not stop even if a command fails. The function returns the last error encountered, if any.
func OverrideEnv ¶
OverrideEnv overrides environment variables stored in env with ones from ovr. It ignores environment variables with empty values.
Types ¶
type Executable ¶
type Recipe ¶
type Recipe struct {
Name string `xml:"name,attr"`
Executable []Executable `xml:"executable"`
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Package bash provides simple interface to a shell session.
|
Package bash provides simple interface to a shell session. |
|
cmd
|
|
|
ciexec
command
cmd/ciexec executes CI configuration file like it was a shell script.
|
cmd/ciexec executes CI configuration file like it was a shell script. |